---
title: <span class="badge object-type-scalar"></span> Feet
---
# <span class="badge object-type-scalar"></span> Feet

Length: feet (ft)

## Definition

```python
# Length: feet (ft)
Feet: typing.Literal["lengthft"] = "lengthft"
```
